==> flutter_ads-0.2.5.tar.gz: ios/Classes/FlutterAdsPlugin.m <==
// create by shupeng

#import "FlutterAdsPlugin.h"
#import "FlutterAdsSplashViewFactory.h"
#import "FlutterAdsBannerViewFactory.h"
#import "FlutterAdsNativeViewFactory.h"
#import "FlutterAdsFloatViewFactory.h"
#import <NOVAdKit/NOVAAdManager.h>

@interface FlutterAdsPlugin ();;
@end

@implementation FlutterAdsPlugin
+ (FlutterAdsPlugin *)shared {
    static id _shared = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        _shared = [[self alloc] init];
    });

    return _shared;
}

+ (void)registerWithRegistrar:(NSObject <FlutterPluginRegistrar> *)registrar {
    // 广告SDK初始化
    [[NOVAdManager shared] setup];

    FlutterMethodChannel *channel = [FlutterMethodChannel
            methodChannelWithName:@"flutter_ads"
                  binaryMessenger:[registrar messenger]];
    [registrar addMethodCallDelegate:[self shared] channel:channel];
    // 开屏广告
    [registrar registerViewFactory:[[FlutterAdsSplashViewFactory alloc] initWithMessenger:registrar.messenger]
                            withId:@"plugins.nova.ads/splashview"];
    // banner广告
    [registrar registerViewFactory:[[FlutterAdsBannerViewFactory alloc] initWithMessenger:registrar.messenger]
                            withId:@"plugins.nova.ads/bannerview"];

    // 原生广告
    [registrar registerViewFactory:[[FlutterAdsNativeViewFactory alloc] initWithMessenger:registrar.messenger]
                            withId:@"plugins.nova.ads/nativeview"];

    // Float广告
    [registrar registerViewFactory:[[FlutterAdsFloatViewFactory alloc] initWithMessenger:registrar.messenger]
                            withId:@"plugins.nova.ads/float"];

    // 激励视频回调
    [self shared].rewardChannel = [FlutterBasicMessageChannel messageChannelWithName:@"plugins.nova.ads.event/reward"
                                                                     binaryMessenger:[registrar messenger]
                                                                               codec:[FlutterStringCodec sharedInstance]];
    // 插屏视频回调
    [self shared].interstitialChannel = [FlutterBasicMessageChannel messageChannelWithName:@"plugins.nova.ads.event/insert"
                                                                           binaryMessenger:[registrar messenger]
                                                                                     codec:[FlutterStringCodec sharedInstance]];

    // CPM回调
    [self shared].cpmChannel = [FlutterBasicMessageChannel messageChannelWithName:@"plugins.nova.ads.event/cpm"
                                                                           binaryMessenger:[registrar messenger]
                                                                                     codec:[FlutterStringCodec sharedInstance]];
}


- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    if ([@"getPlatformVersion" isEqualToString:call.method]) {
        result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else if ([@"initRewardVideo" isEqualToString:call.method]) {
        [self showReward];
    } else if ([@"initInsertVideo" isEqualToString:call.method]) {
        [self showInterstitial];
    } elseif ([@"initCpmPopAd" isEqualToString:call.method]) {
        [self showCPM];
    } else {
        result(FlutterMethodNotImplemented);
    }
}

- (void)showReward {
    UIViewController *rootViewController = [[[[UIApplication sharedApplication] delegate] window] rootViewController];
    [[NOVAdManager shared] showRewardFromRootVC:rootViewController
                                       callback:^(NOVAdState state, NSError *error) {
                                           if (state == NOVAdCanNotShowAd
                                                   || state == NOVAdWillClose
                                                   || state == NOVAdDidFailed) {
                                               [self.rewardChannel sendMessage:@"finish"];
                                           }
                                       }];
}

- (void)showInterstitial {
    UIViewController *rootViewController = [[[[UIApplication sharedApplication] delegate] window] rootViewController];
    [[NOVAdManager shared] showInterstitialFromRootVC:rootViewController
                                       callback:^(NOVAdState state, NSError *error) {
                                           if (state == NOVAdCanNotShowAd
                                                   || state == NOVAdWillClose
                                                   || state == NOVAdDidFailed) {
                                               [self.interstitialChannel sendMessage:@"finish"];
                                           }
                                       }];
}

- (void)showCPM {
    UIViewController *rootViewController = [[[[UIApplication sharedApplication] delegate] window] rootViewController];
    [[NOVAdManager shared] showCPMHFromRootVC:rootViewController
                                       callback:^(NOVAdState state, NSError *error) {
                                           if (state == NOVAdCanNotShowAd
                                                   || state == NOVAdWillClose
                                                   || state == NOVAdDidFailed) {
                                               [self.cpmChannel sendMessage:@"finish"];
                                           }
                                       }];
}

@end

==> flutter_ads-0.2.6.tar.gz: ios/Classes/FlutterAdsPlugin.m <==
// create by shupeng

#import "FlutterAdsPlugin.h"
#import "FlutterAdsSplashViewFactory.h"
#import "FlutterAdsBannerViewFactory.h"
#import "FlutterAdsNativeViewFactory.h"
#import "FlutterAdsFloatViewFactory.h"
#import <NOVAdKit/NOVAAdManager.h>

@interface FlutterAdsPlugin ();;
@end

@implementation FlutterAdsPlugin
+ (FlutterAdsPlugin *)shared {
    static id _shared = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        _shared = [[self alloc] init];
    });

    return _shared;
}

+ (void)registerWithRegistrar:(NSObject <FlutterPluginRegistrar> *)registrar {
    // 广告SDK初始化
    [[NOVAdManager shared] setup];

    FlutterMethodChannel *channel = [FlutterMethodChannel
            methodChannelWithName:@"flutter_ads"
                  binaryMessenger:[registrar messenger]];
    [registrar addMethodCallDelegate:[self shared] channel:channel];
    // 开屏广告
    [registrar registerViewFactory:[[FlutterAdsSplashViewFactory alloc] initWithMessenger:registrar.messenger]
                            withId:@"plugins.nova.ads/splashview"];
    // banner广告
    [registrar registerViewFactory:[[FlutterAdsBannerViewFactory alloc] initWithMessenger:registrar.messenger]
                            withId:@"plugins.nova.ads/bannerview"];

    // 原生广告
    [registrar registerViewFactory:[[FlutterAdsNativeViewFactory alloc] initWithMessenger:registrar.messenger]
                            withId:@"plugins.nova.ads/nativeview"];

    // Float广告
    [registrar registerViewFactory:[[FlutterAdsFloatViewFactory alloc] initWithMessenger:registrar.messenger]
                            withId:@"plugins.nova.ads/float"];

    // 激励视频回调
    [self shared].rewardChannel = [FlutterBasicMessageChannel messageChannelWithName:@"plugins.nova.ads.event/reward"
                                                                     binaryMessenger:[registrar messenger]
                                                                               codec:[FlutterStringCodec sharedInstance]];
    // 插屏视频回调
    [self shared].interstitialChannel = [FlutterBasicMessageChannel messageChannelWithName:@"plugins.nova.ads.event/insert"
                                                                           binaryMessenger:[registrar messenger]
                                                                                     codec:[FlutterStringCodec sharedInstance]];

    // CPM回调
    [self shared].cpmChannel = [FlutterBasicMessageChannel messageChannelWithName:@"plugins.nova.ads.event/cpm"
                                                                           binaryMessenger:[registrar messenger]
                                                                                     codec:[FlutterStringCodec sharedInstance]];
}


- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    if ([@"getPlatformVersion" isEqualToString:call.method]) {
        result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else if ([@"initRewardVideo" isEqualToString:call.method]) {
        [self showReward];
    } else if ([@"initInsertVideo" isEqualToString:call.method]) {
        [self showInterstitial];
    } elseif ([@"initCpmPopAd" isEqualToString:call.method]) {
        [self showCPM];
    } else {
        result(FlutterMethodNotImplemented);
    }
}

- (void)showReward {
    UIViewController *rootViewController = [[[[UIApplication sharedApplication] delegate] window] rootViewController];
    [[NOVAdManager shared] showRewardFromRootVC:rootViewController
                                       callback:^(NOVAdState state, NSError *error) {
                                           if (state == NOVAdCanNotShowAd
                                                   || state == NOVAdWillClose
                                                   || state == NOVAdDidFailed) {
                                               [self.rewardChannel sendMessage:@"finish"];
                                           }
                                       }];
}

- (void)showInterstitial {
    UIViewController *rootViewController = [[[[UIApplication sharedApplication] delegate] window] rootViewController];
    [[NOVAdManager shared] showInterstitialFromRootVC:rootViewController
                                       callback:^(NOVAdState state, NSError *error) {
                                           if (state == NOVAdCanNotShowAd
                                                   || state == NOVAdWillClose
                                                   || state == NOVAdDidFailed) {
                                               [self.interstitialChannel sendMessage:@"finish"];
                                           }
                                       }];
}

- (void)showCPM {
    UIViewController *rootViewController = [[[[UIApplication sharedApplication] delegate] window] rootViewController];
    [[NOVAdManager shared] showCPMFromRootVC:rootViewController
                                       callback:^(NOVAdState state, NSError *error) {
                                           if (state == NOVAdCanNotShowAd
                                                   || state == NOVAdWillClose
                                                   || state == NOVAdDidFailed) {
                                               [self.cpmChannel sendMessage:@"finish"];
                                           }
                                       }];
}

@end
